# Changelog

## gsdesign-python 0.0.1

### New features

- Ported the canonical `gridpts`, `h1`, and `hupdate` numerical integration
  routines from gsDesign, complete with typed public exports (#1).

### Testing

- Added unit tests with high-precision reference fixtures and regeneration
  tooling to keep the Python implementation aligned with the R package
  gsDesign2 (#1).
